@@ -5,7 +5,7 @@
 #' This function retrieves drug molecules in InChI format from the CAS database.
 #' CAS database only provides InChI data, so here we return the molecule
 #' in InChI format, users could convert them to SMILES format using
-#' Open Babel (\url{http://openbabel.org/}) or other third-party tools.
+#' Open Babel or other third-party tools.
 #'
 #' @param id A character vector, as the CAS drug ID.
 #' @param parallel An integer, the parallel parameter, indicates how many
@@ -21,8 +21,6 @@
 #'
 #' @export getMolFromCAS
 #'
-#' @importFrom RCurl getURLAsynchronous
-#'
 #' @examples
 #' id = '52-67-5'  # Penicillamine
 #' \donttest{
@@ -39,7 +37,7 @@ getMolFromCAS = function (id, parallel = 5) {
     InChIURL = paste0('http://www.chemnet.com/cas/supplier.cgi?terms=', id,
                       '&exact=dict')
 
-    InChITxt = getURLAsynchronous(url = InChIURL, perform = parallel)
+    InChITxt = get_url_parallel(url = InChIURL, total_con = parallel)
 
     n = length(id)
     tmp1 = rep(NA, n)
