@@ -15,8 +15,6 @@
 #'
 #' @export extractDrugAtomCount
 #'
-#' @importFrom rcdk eval.desc
-#'
 #' @examples
 #' smi = system.file('vignettedata/FDAMDD.smi', package = 'Rcpi')
 #' \donttest{
@@ -25,12 +23,5 @@
 #' head(dat)}
 
 extractDrugAtomCount = function (molecules, silent = TRUE) {
-
-    x = eval.desc(
-        molecules,
-        'org.openscience.cdk.qsar.descriptors.molecular.AtomCountDescriptor',
-        verbose = !silent)
-
-    return(x)
-
+    evaluateDescriptor(molecules, type = 'AtomCountDescriptor', silent = silent)
 }
