@@ -16,16 +16,8 @@
 #' each column represents one feature.
 #' This function returns one column named \code{fragC}.
 #'
-#' @keywords extractDrugFragmentComplexity Fragment Complexity
-#'
-#' @aliases extractDrugFragmentComplexity
-#'
-#' @author Nan Xiao <\url{https://nanx.me}>
-#'
 #' @export extractDrugFragmentComplexity
 #'
-#' @importFrom rcdk eval.desc
-#'
 #' @references
 #' Nilakantan, R. and Nunn, D.S. and Greenblatt,
 #' L. and Walker, G. and Haraki, K. and Mobilio, D.,
@@ -42,12 +34,5 @@
 #' head(dat)}
 
 extractDrugFragmentComplexity = function (molecules, silent = TRUE) {
-
-    x = eval.desc(
-        molecules,
-        'org.openscience.cdk.qsar.descriptors.molecular.FragmentComplexityDescriptor',
-        verbose = !silent)
-
-    return(x)
-
+    evaluateDescriptor(molecules, type = 'FragmentComplexityDescriptor', silent = silent)
 }
