@@ -13,16 +13,8 @@
 #' each column represents one feature.
 #' This function returns one column named \code{MolIP}.
 #'
-#' @keywords extractDrugIPMolecularLearning Ionization Potential
-#'
-#' @aliases extractDrugIPMolecularLearning
-#'
-#' @author Nan Xiao <\url{https://nanx.me}>
-#'
 #' @export extractDrugIPMolecularLearning
 #'
-#' @importFrom rcdk eval.desc
-#'
 #' @examples
 #' smi = system.file('vignettedata/FDAMDD.smi', package = 'Rcpi')
 #' \donttest{
@@ -31,12 +23,5 @@
 #' head(dat)}
 
 extractDrugIPMolecularLearning = function (molecules, silent = TRUE) {
-
-    x = eval.desc(
-        molecules,
-        'org.openscience.cdk.qsar.descriptors.molecular.IPMolecularLearningDescriptor',
-        verbose = !silent)
-
-    return(x)
-
+    evaluateDescriptor(molecules, type = 'IPMolecularLearningDescriptor', silent = silent)
 }
